@@ -255,6 +255,24 @@
 ;; V1.55 05Jan2005 Kevin Ryde <user42@zip.com.au>
 ;;  - adds gnus support to debian-bug-get-bug-as-email, bringing the bug
 ;;   messages up in a gnus group. (Closes: #288469)
+;; V1.55 05Jan2005 Peter S Galbraith <psg@debian.org>
+;;   debian-bug-package: skip over mml directives in new drafts.
+;;   Thanks to Luca Capello <luca@pca.it> (Closes: #336466)
+;; V1.56 03Nov2005 Peter S Galbraith <psg@debian.org>
+;;   - debian-bug-prompt-bug-number: new function to prompt user for a bug
+;;     number using number under point if any.
+;;   - debian-bug-web-bug: use it.
+;;   - debian-bug-web-this-bug: deleted (no longer needed).
+;;   - debian-bug-get-bug-as-file: use it.
+;;   - debian-bug-get-bug-as-email: use it.
+;;     (Closes: #337233)
+;; V1.57 03Nov2005 Peter S Galbraith <psg@debian.org>
+;;   - Swap CC: for X-Debbugs-CC: in mail header (Closes: #208570)
+;; V1.58 05Nov2005 Peter S Galbraith <psg@debian.org>
+;;   - debian-bug-wnpp: skip over mml directives in new drafts.
+;;   Thanks to Luca Capello <luca@pca.it> (Closes: #337659)
+;; V1.59 14Nov2005 Peter S Galbraith <psg@debian.org>
+;;   - Search for "^cc:" instead of simply "cc:" in Bug #208570 change.
 ;; ----------------------------------------------------------------------------
 
 ;;; Todo (Peter's list):
@@ -625,6 +643,10 @@ Reportbug may have sent an empty report!")))
                (string-equal " *nntpd*" (buffer-name)))
           (set-buffer "*mail*"))   ; Bug in emacs21.1?  Moves to " *nntpd*"
       (goto-char (point-min))
+      (when (re-search-forward "^cc:" nil t)
+        (delete-region (match-beginning 0)(match-end 0))
+        (insert "X-Debbugs-CC:"))
+      (goto-char (point-min))
       (cond
        ((re-search-forward "To: " nil t)
         (insert debian-bug-mail-address))
@@ -645,6 +667,8 @@ Reportbug may have sent an empty report!")))
       (require 'sendmail)
       (goto-char (mail-header-end))
       (forward-line 1)
+      (if (looking-at "^<#secure")      ;Skip over mml directives
+          (forward-line 1))
       (message "Getting package information from system...")
       (debian-bug-prefill-report package severity)
       (message "Getting package information from system...done")
@@ -715,6 +739,8 @@ Optional argument ACTION can be provided in programs."
     (require 'sendmail)
     (goto-char (mail-header-end))
     (forward-line 1)
+    (if (looking-at "^<#secure")      ;Skip over mml directives
+        (forward-line 1))
     (save-excursion
       (goto-char (point-min))
       (if debian-bug-use-From-address
@@ -1392,11 +1418,29 @@ With optional argument prefix ARCHIVED, display archived bugs."
       (message "Looking up developer web page for package %s via browse-url"
                pkg-name))))
 
+(defun debian-bug-prompt-bug-number (prompt)
+  "Prompt the user for a bug number using PROMPT."
+  (let ((default-number)
+        (item (word-at-point)))
+    ;; First see if there's a number under point
+    (if (and item
+	     (string-match "^[0-9]+[0-9]$" item))
+        (setq default-number (match-string-no-properties 0 item))
+      ;; If not, try for mail message header
+      (save-excursion
+        (goto-char (point-min))
+        (if (re-search-forward "\\([0-9]+\\)@bugs.debian.org"
+                               (mail-header-end) t)
+            (setq default-number (match-string-no-properties 1)))))
+    (list (completing-read (if default-number
+                               (format "%s [%s]: " prompt default-number)
+                             (format "%s: " prompt))
+                           debian-bug-alist nil nil nil nil default-number))))
+
 ;;;###autoload
 (defun debian-bug-web-bug (&optional bug-number)
   "Browse the BTS for BUG-NUMBER via `browse-url'."
-  (interactive (list (completing-read "Bug number to lookup: "
-                                      debian-bug-alist nil nil)))
+  (interactive (debian-bug-prompt-bug-number "Bug number to lookup"))
   (if (not (featurep 'browse-url))
       (progn
         (load "browse-url" nil t)
@@ -1413,9 +1457,11 @@ With optional argument prefix ARCHIVED, display archived bugs."
     (message "Looking up bug number %s via browse-url" bug-number)))
 
 ;;;###autoload
-(defun debian-bug-web-this-bug ()
-  "Browse the BTS via `browse-url' for the bug report number under point."
-  (interactive)
+(defun debian-bug-web-this-bug-under-mouse (EVENT)
+  "Browse the BTS via `browse-url' for the bug report number under mouse.
+In a program, mouse location is in EVENT."
+  (interactive "e")
+  (mouse-set-point EVENT)
   (if (not (looking-at "[0-9]"))
       (error "Not a number under point/mouse"))
   (save-excursion
@@ -1424,14 +1470,6 @@ With optional argument prefix ARCHIVED, display archived bugs."
         (let ((bug-number (match-string 0)))
           (debian-bug-web-bug bug-number)))))
 
-;;;###autoload
-(defun debian-bug-web-this-bug-under-mouse (EVENT)
-  "Browse the BTS via `browse-url' for the bug report number under mouse.
-In a program, mouse location is in EVENT."
-  (interactive "e")
-  (mouse-set-point EVENT)
-  (debian-bug-web-this-bug))
-
 ;;;###autoload
 (defun debian-bug-web-packages ()
   "Search Debian web page for this package via `browse-url'."
@@ -1591,8 +1629,7 @@ If SUBMENU is t, then check for current sexp submenu only."
 ;;;###autoload
 (defun debian-bug-get-bug-as-file (&optional bug-number)
   "Read bug report #BUG-NUMBER as a regular file."
-  (interactive (list (completing-read "Bug number to fetch: "
-                                      debian-bug-alist nil nil)))
+  (interactive (debian-bug-prompt-bug-number "Bug number to fetch"))
   (let ((filename (debian-bug-wget-mbox bug-number)))
     (find-file filename)
     (text-mode)))
@@ -1607,8 +1644,7 @@ If SUBMENU is t, then check for current sexp submenu only."
                           (not (and (fboundp 'gnus-alive-p)
                                     (gnus-alive-p))))
                      (error "Please start `gnus' (or `gnus-slave') first"))
-                 (list (completing-read "Bug number to fetch: "
-                                        debian-bug-alist nil nil))))
+                 (debian-bug-prompt-bug-number "Bug number to fetch")))
   (cond
    ((and (eq mail-user-agent 'mh-e-user-agent)
          (featurep 'mh-inc))
@@ -1714,7 +1750,7 @@ Only decodes if `rfc2047-decode-string' is available."
 	(goto-char (point-min))
         (while
             (re-search-forward
-             "\\(<H2><a name.*</a>\\(.+\\)</H2>\\)\\|\\(<li><a href=\"\\(bugreport.cgi\\?bug=\\([0-9]+\\)\\)\">\\(#[0-9]+: \\(.+\\)\\)</a>\\)"
+             "\\(<H2.*</a>\\(.+\\)</H2>\\)\\|\\(<li><a href=\"\\(bugreport.cgi\\?bug=\\([0-9]+\\)\\)\">\\(#[0-9]+: \\(.+\\)\\)</a>\\)"
              nil t)
           (let ((type (match-string 2))
               ;;(URL (match-string 4))
@@ -1730,8 +1766,9 @@ Only decodes if `rfc2047-decode-string' is available."
              (t
               (setq bug-alist (cons (list bugnumber description) bug-alist))
               (when bugs-are-open-flag
-                (when (and (re-search-forward "Reported by: <a href=[^>]+>"
-                                              nil t)
+                (when (and (re-search-forward
+                            "Reported by: <a class=\"submitter\" href=\"pkgreport.cgi\\?submitter=[^;]+;arch=source\">"
+                            nil t)
                            (or (looking-at "&quot;\\(.*\\)&quot; &lt;")
                                (looking-at "\\(.*\\) &lt;")))
                   (setq shortdescription
